%global tarballname signing-party
%global debian_version 1.1.4
Name:           pgp-tools
Version:        %{debian_version}
Release:        1%{?dist}
Summary:        Collection of several utilities related to OpenPGP
Group:          Applications/System
License:        BSD and GPLv2+
URL:            http://pgp-tools.alioth.debian.org/
Source0:        http://ftp.debian.org/debian/pool/main/s/%{tarballname}/%{tarballname}_%{debian_version}.orig.tar.gz
Patch0:         %{name}-1.1-drop-pgpring.patch
Patch1:		%{name}-1.1.4-paper.patch
# for gpgdir test suite
%if 0%{?fedora} > 18
BuildRequires:  perl-podlators
%endif
BuildRequires:  gpg, perl(GnuPG::Interface), perl(Term::ReadKey), perl(Class::MethodMaker)
BuildRequires:  perl(Digest::MD5)
Requires:       gpg, perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))
Requires:       coreutils, sed, /usr/sbin/sendmail, perl(Locale::Recode)
Requires:       perl(Class::MethodMaker), perl(Term::ReadKey)
# for pgpring
Requires:      mutt
# for gpg-key2ps
Requires:      libpaper	
Buildroot:     %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

%description
This is a collection of several projects relating to OpenPGP.

* caff: CA - Fire and Forget signs and mails a key
* pgp-clean: removes all non-self signatures from key
* pgp-fixkey: removes broken packets from keys
* gpg-mailkeys: simply mail out a signed key to its owner
* gpg-key2ps: generate PostScript file with fingerprint paper strips
* gpgdir: recursive directory encryption tool
* gpglist: show who signed which of your UIDs
* gpgsigs: annotates list of GnuPG keys with already done signatures
* keylookup: ncurses wrapper around gpg --search
* gpgparticipants: create list of party participants for the organiser
* gpgwrap: a passphrase wrapper
* keyanalyze: minimum signing distance (MSD) analysis on keyrings
* sig2dot: converts a list of GnuPG signatures to a .dot file
* springgraph: creates a graph from a .dot file


%prep
%setup -q -n %{tarballname}-%{version}
# fix gpgdir library path lookup as we're using system-provided libraries
sed -i -e "s,/usr/lib/gpgdir,," gpgdir/gpgdir
%patch0 -p1
%patch1 -p1

%build
make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{_bindir}
mkdir -p $RPM_BUILD_ROOT%{_mandir}/man1
make install DESTDIR=$RPM_BUILD_ROOT || :
# apps with no 'make install'
for f in caff pgp-clean pgp-fixkey ; do
install -m 755 caff/$f $RPM_BUILD_ROOT%{_bindir}/
done
install -m 755 gpg-key2ps/gpg-key2ps $RPM_BUILD_ROOT%{_bindir}/
install -m 755 gpgdir/gpgdir $RPM_BUILD_ROOT%{_bindir}/
install -m 755 gpglist/gpglist $RPM_BUILD_ROOT%{_bindir}/
install -m 755 gpgwrap/bin/gpgwrap $RPM_BUILD_ROOT%{_bindir}/
install -m 755 gpg-mailkeys/gpg-mailkeys $RPM_BUILD_ROOT%{_bindir}/
install -m 755 gpgparticipants/gpgparticipants $RPM_BUILD_ROOT%{_bindir}/

# nuke apps creating their own docs dir
rm -rf ${RPM_BUILD_ROOT}/usr/share/doc
# find all manpages wherever they are hiding
DIRS="$(find . -maxdepth 1 -type d | sed -e 's:^.$::' -e 's:^./::')"
for man in `find $DIRS -type f -name "*.1" -print`
do
    install -m644 $man $RPM_BUILD_ROOT%{_mandir}/man1
done

# nuke our copy of pgpring manpage
rm ${RPM_BUILD_ROOT}/%{_mandir}/man1/pgpring.1


rm -rf __fedora_docs
mkdir __fedora_docs
cp -a $DIRS __fedora_docs/

#  cleanup to leave docs only...
find __fedora_docs/ -type f \( -perm +0111 -o -name Makefile -o -name "*.[1-9]" \) -print | xargs rm -f
find __fedora_docs -type d -name src -exec rm -rf \{\} \; || :
rm -rf __fedora_docs/keyanalyze/pgpring
rm -rf __fedora_docs/keyanalyze/*.[cho]
rm     __fedora_docs/gpgdir/INSTALL
rm -rf __fedora_docs/gpgdir/packaging
rm -rf __fedora_docs/gpgdir/test
rm -rf __fedora_docs/gpgwrap/{bin,doc}
rm -rf __fedora_docs/gpglist
rm -rf __fedora_docs/gpgparticipants
mv __fedora_docs/keylookup/COPYING .

%clean
rm -rf $RPM_BUILD_ROOT

%check
pushd gpgdir/test
./gpgdir_test.pl
RC=0
grep "STATUS: fail" output/*.test > /dev/null 2>&1 && RC=1
popd
exit $RC

%files
%defattr(-,root,root,-)
%{_bindir}/*
%{_mandir}/man1/*
%{_datadir}/signing-party
%doc README COPYING
%doc __fedora_docs/*

%changelog
* Thu Sep 12 2013 Jochen Schmitt <Jochen herr-schmitt de> - 1.1.4-1
- Initial SPEC file for EL-5

